Operations Module
=================

This module contains various video operations.

Basic Operations
----------------

.. automodule:: fmusvid.operations.basic
   :members:
   :undoc-members:

Composition Operations
----------------------

.. automodule:: fmusvid.operations.composition
   :members:
   :undoc-members:

Transition Effects
------------------

.. automodule:: fmusvid.operations.transitions
   :members:
   :undoc-members:

Text and Subtitles
------------------

.. automodule:: fmusvid.operations.text
   :members:
   :undoc-members:

.. automodule:: fmusvid.operations.subtitle
   :members:
   :undoc-members:

Analysis
--------

.. automodule:: fmusvid.operations.analysis
   :members:
   :undoc-members:
